# Change Log

## [0.3.1](https://github.com/dldevinc/django-flatly/tree/v0.3.1) - 2023-01-09

### Features

- Add Python 3.11 support (no code changes were needed, but now we test this release).

## [0.3.0](https://github.com/dldevinc/django-flatly/tree/v0.3.0) - 2022-08-15

### Features

-   Added support for Django 4.1.

## [0.2.2](https://github.com/dldevinc/django-flatly/tree/v0.2.2) - 2022-01-18

### Bug Fixes

-   Add an ability to serve home page.

## [0.2.1](https://github.com/dldevinc/django-flatly/tree/v0.2.1) - 2021-03-02

-   Fix trailing slash for flatly pages

## [0.2.0](https://github.com/dldevinc/django-flatly/tree/v0.2.0) - 2020-07-14

-   Add `FLATLY_CACHE_ENABLED` setting
-   Support Django's default `APPEND_SLASH` behaviour
